********************************************************************************************************************
* STEP | GENERATING DERIVED VARIABLES FROM THE BACKGROUND QUESTIONNAIRE & LITERACY ASSESSMENT DATA
*
*	DO-FILE 4: FAMILY-RELATED VARIABLES
*
* N. Millan's January 7, 2013 do-file
*
* Created: January 7, 2013
* Last updated: Dec 21, 2013
********************************************************************************************************************

/*
As of August 1, 2013 the STEP countries are:
	- Bolivia
	- Colombia
	- Laos
	- Sri Lanka
	- Vietnam
	- Yunnan
	- Ukraine

This do-file uses the STEP Working data files to generate family-related variables using the household questionnaire data (Module 7).

It is based on Natalia Millan's January 7, 2013 do-file.
*/


global pathworkingdata 
global pathHHroster


**************************************************************** LOOP THROUGH ALL COUNTRIES ************************************************************************

foreach country in "Bolivia" "Laos" "Sri Lanka" "Vietnam" "Yunnan" "Colombia" {
	
	use "$pathworkingdata/STEP `country'_working.dta", clear
	sort cluster hhn idcode
	save "$pathworkingdata/STEP `country'_working.dta", replace
	
	use "$pathdataready/STEP `country'_HH Roster_S10.dta", clear
	keep cluster hhn idcode m1a*
	sort cluster hhn idcode
	merge m:1 cluster hhn idcode using "$pathworkingdata/STEP `country'_working.dta"
	drop _merge	
	
	replace country="`country'"

	if country=="Bolivia" {
		*MOTHER'S EDUCATION
		gen mother_educ=. if m7a_q14==99
		replace mother_educ=0 if m7a_q14==1|m7a_q14==2   /*<ISCED 1*/
		replace mother_educ=1 if m7a_q14==3			/*ISCED 1*/
		replace mother_educ=2 if m7a_q14==5 |m7a_q14==4/*ISCED 2 and 3*/
		replace mother_educ=3 if m7a_q14==7|m7a_q14==8|m7a_q14==6  /*ISCED 4 & above*/

		bysort cluster hhn: egen x=max(m7a_q13)  /*Mother's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==99
		bysort cluster hhn: egen xxx=max(temp)  /*Mother's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1|xxx==2   /*ISCED < 1*/
		replace xy=1 if xxx==3      /*ISCED 1*/
		replace xy=2 if xxx==4 /*ISCED 2*/
		replace xy=2 if xxx==5 /*ISCED 3*/
		replace xy=3 if xxx==7|xxx==8|xxx==6 /*ISCED 4 and above*/

		replace mother_educ=xy if mother_educ==.
		replace mother_educ=4 if mother_educ==. /*DK/MISSING*/
		drop x* temp
	
		label var mother_edu "Mother's education" 

		*FATHER'S EDUCATION
		gen father_educ=. if m7a_q17==99
		replace father_educ=0 if m7a_q17==1|m7a_q17==2   /*NONE OR LESS THAN PRIMARY*/
		replace father_educ=1 if m7a_q17==3	/*ISCED 1*/
		replace father_educ=2 if m7a_q17==5| m7a_q17==4 /*ISCED 2 and 3*/
		replace father_educ=3 if m7a_q17==7|m7a_q17==8 |m7a_q17==6  /*ISCED 4 & above*/

		bysort cluster hhn: egen x=max(m7a_q16)  /*father's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==99
		bysort cluster hhn: egen xxx=max(temp)  /*father's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1|xxx==2   /*ISCED < 1*/
		replace xy=1 if xxx==3      /*ISCED 1*/
		replace xy=2 if xxx==4 /*ISCED 2*/
		replace xy=2 if xxx==5 /*ISCED 3*/
		replace xy=3 if xxx==7|xxx==8|xxx==6 /*ISCED 4 and above*/

		replace father_educ=xy if father_educ==.
		replace father_educ=4 if father_educ==. /*DK/MISSING*/
		label var father_edu "Father's education" 
		drop x* temp
	}
	
	
	if country=="Colombia" {
		*MOTHER'S EDUCATION
		gen mother_educ=. if m7a_q14==99
		replace mother_educ=0 if m7a_q14==1|m7a_q14==2   /*<ISCED 1*/
		replace mother_educ=1 if m7a_q14==3			/*ISCED 1*/
		replace mother_educ=2 if m7a_q14==5 |m7a_q14==4/*ISCED 2 and 3*/
		replace mother_educ=3 if m7a_q14==7|m7a_q14==8|m7a_q14==6  /*ISCED 4 & above*/

		bysort cluster hhn: egen x=max(m7a_q13)  /*Mother's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==99
		bysort cluster hhn: egen xxx=max(temp)  /*Mother's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1|xxx==2   /*ISCED < 1*/
		replace xy=1 if xxx==3      /*ISCED 1*/
		replace xy=2 if xxx==4 /*ISCED 2*/
		replace xy=2 if xxx==5 /*ISCED 3*/
		replace xy=3 if xxx==7|xxx==8|xxx==6 /*ISCED 4 and above*/

		replace mother_educ=xy if mother_educ==.
		replace mother_educ=4 if mother_educ==. /*DK/MISSING*/
		drop x* temp
	
		label var mother_edu "Mother's education" 

		*FATHER'S EDUCATION
		gen father_educ=. if m7a_q17==99
		replace father_educ=0 if m7a_q17==1|m7a_q17==2   /*NONE OR LESS THAN PRIMARY*/
		replace father_educ=1 if m7a_q17==3	/*ISCED 1*/
		replace father_educ=2 if m7a_q17==5| m7a_q17==4 /*ISCED 2 and 3*/
		replace father_educ=3 if m7a_q17==7|m7a_q17==8 |m7a_q17==6  /*ISCED 4 & above*/

		bysort cluster hhn: egen x=max(m7a_q16)  /*father's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==99
		bysort cluster hhn: egen xxx=max(temp)  /*father's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1|xxx==2   /*ISCED < 1*/
		replace xy=1 if xxx==3      /*ISCED 1*/
		replace xy=2 if xxx==4 /*ISCED 2*/
		replace xy=2 if xxx==5 /*ISCED 3*/
		replace xy=3 if xxx==7|xxx==8|xxx==6 /*ISCED 4 and above*/

		replace father_educ=xy if father_educ==.
		replace father_educ=4 if father_educ==. /*DK/MISSING*/
		label var father_edu "Father's education" 
		drop x* temp
	}

	
	if country=="Laos" {
		*MOTHER'S EDUCATION
		gen mother_educ=0 if m7a_q14==1  		    /*NONE OR LESS THAN PRIMARY*/
		replace mother_educ=1 if m7a_q14==2 /*PRIMARY*/
		replace mother_educ=2 if m7a_q14==4	| m7a_q14==3	       /*LOWER & UPPER SECONDARY*/
		replace mother_educ=2 if m7a_q14==5   	       /*CONSIDER LOW DIPLOMA TO BE EQUAL TO UPPER SECONDARY*/
		replace mother_educ=3 if m7a_q14==6   	       /*POST-SECONDARY, NON-TERTIARY*/
		replace mother_educ=3 if m7a_q14==7|m7a_q14==8 /*TERTIARY*/
		*Convert education variable m1a_q09 to ISCED
		gen     roster_ISCED=0 if m1a_q09==1
		replace roster_ISCED=1 if m1a_q09==2
		replace roster_ISCED=2 if m1a_q09==3 
		replace roster_ISCED=2 if m1a_q09==2 &  m1a_q09a==5
		replace roster_ISCED=3 if  m1a_q09==4 
		replace roster_ISCED=3 if m1a_q09==3 & m1a_q09a==5
		replace roster_ISCED=4 if m1a_q09a==6
		replace roster_ISCED=5 if m1a_q09a==7 |m1a_q09a==8 |m1a_q09a==9
		replace roster_ISCED=5 if m1a_q09a==10
		bysort cluster hhn: egen x=max(m7a_q13)  /*Mother's id code*/

		gen temp=roster_ISCED if idcode==x 
		bysort cluster hhn: egen xxx=max(temp)  
		replace mother_educ=0 if xxx==0 & mother_educ==.
		replace mother_educ=1 if xxx==1 & mother_educ==.
		replace mother_educ=2 if xxx==3|xxx==2 & mother_educ==. /*LOWER & UPPPER*/
		replace mother_educ=3 if xxx==5|xxx==4 & mother_educ==. /*ISCED 4 & above*/
		replace mother_educ=4 if mother_educ==. /*DK/MISSING*/
		replace mother_educ=. if elegido!=1
		drop x* temp
		label var mother_edu "Mother's education" 
		
		*FATHER'S EDUCATION
		gen     father_educ=0 if m7a_q14==1  		   	/*NONE OR LESS THAN PRIMARY*/
		replace father_educ=1 if m7a_q14==2 			/*PRIMARY SECONDARY*/
		replace father_educ=2 if m7a_q14==4	| m7a_q14==3	       /*UPPER & LOWER SECONDARY*/
		replace father_educ=2 if m7a_q14==5   	       /*CONSIDER LOW DIPLOMA TO BE EQUAL TO UPPER SECONDARY*/
		replace father_educ=3 if m7a_q14==7|m7a_q14==8 | m7a_q14==6 /*ISCED 4 & above*/

		bysort cluster hhn: egen x=max(m7a_q16)  /*Father's id code*/
		gen temp=roster_ISCED if idcode==x 
		bysort cluster hhn: egen xxx=max(temp)  
		replace father_educ=0 if xxx==0 & father_educ==.
		replace father_educ=1 if xxx==1 & father_educ==.
		replace father_educ=2 if xxx==2|xxx==3 & father_educ==.
		replace father_educ=3 if xxx==4|xxx==5 & father_educ==.
		replace father_educ=4 if father_educ==. /*DK/MISSING*/
		replace father_educ=. if elegido!=1
		drop x* temp roster_IS
		label var father_edu "Father's education" 	
	}
	

	if country=="Sri Lanka" {
		*MOTHER'S EDUCATION
		*Convert education variable m1a_q09 to ISCED
		gen     roster_ISCED=0 if m1a_q09==1   					/*NONE OR LESS THAN PRIMARY*/
		replace roster_ISCED=1 if m1a_q09==2   					/*PRIMARY*/
		replace roster_ISCED=2 if m1a_q09==3  					/*LOWER SECONDARY */
		replace roster_ISCED=3 if m1a_q09==4|m1a_q09==5  	  	/*UPPER SECONDARY: PASSED GCE O/L or A/L*/
		replace roster_ISCED=3 if  m1a_q09==11| m1a_q09==12   	/*UPPER SECONDARY, VOCATIONAL TRAINING (CERTIFICATE), TECHNICAL EDUCATION (DIPLOMA)*/
		replace roster_ISCED=5 if m1a_q09==6|m1a_q09==7 |m1a_q09==8 |m1a_q09==14|m1a_q09==13 /*TERTIARY EDUCATION (BACHELORS, MASTERS, PHD)PROFESSIONAL QUALIFICATION (DIPLOMA)*/

		gen 	mother_educ=0 if m7a_q14==1  		    				/*NONE OR LESS THAN PRIMARY*/
		replace mother_educ=1 if m7a_q14==2								/*PRIMARY*/
		replace mother_educ=2 if m7a_q14==4|m7a_q14==3 |m7a_q14==5      /*LOWER SEC, UPPER SECONDARY (O and A levels)*/
		replace mother_educ=2 if m7a_q14==9|m7a_q14==10         		/*UPPER SECONDARY*/
		replace mother_educ=3 if m7a_q14==6|m7a_q14==7|m7a_q14==8 		/*TERTIARY*/
		replace mother_educ=3 if m7a_q14==11|m7a_q14==12		 		/*TERTIARY*/
		replace mother_educ=. if m7a_q14==99	
                                                           														  															  												  
		bysort cluster hhn: egen x=max(m7a_q13)  /*Mother's id code*/
		gen temp=roster_ISCED if idcode==x 
		bysort cluster hhn: egen xxx=max(temp)  
		replace mother_educ=0 if xxx==0 & mother_educ==. 		/*NONE OR LESS THAN PRIMARY*/
		replace mother_educ=1 if xxx==1 & mother_educ==. 		/*PRIMARY */
		replace mother_educ=2 if xxx==3|xxx==4|xxx==2 & mother_educ==. /*SECONDARY*/
		replace mother_educ=3 if xxx==5 & mother_educ==.    	 /*TERTIARY*/
		replace mother_educ=4 if mother_educ==. 				/*DK/MISSING*/
		replace mother_educ=. if elegido!=1
		drop x* temp
		label var mother_edu "Mother's education" 

		*FATHER'S EDUCATION
		gen 	father_educ=0 if m7a_q17==1  		    			/*NONE OR LESS THAN PRIMARY*/
		replace father_educ=1 if m7a_q17==2                         /*PRIMARY*/
		replace father_educ=2 if m7a_q17==5 | m7a_q17==4  | m7a_q17==3 	     /*LOWER, UPPER SECONDARY: PASSED GCE O/L or A/L */
		replace father_educ=2 if m7a_q17==9|m7a_q17==10         	  /*UPPER SECONDARY*/
		replace father_educ=3 if m7a_q17==6|m7a_q17==7|m7a_q17==8 /*TERTIARY*/
		replace father_educ=3 if m7a_q17==11|m7a_q17==12		 	/*TERTIARY*/	
		replace father_educ=. if m7a_q17==99														

		bysort cluster hhn: egen x=max(m7a_q16)  /*Father's id code*/
		gen temp=roster_ISCED if idcode==x 
		bysort cluster hhn: egen xxx=max(temp)  
		replace father_educ=0 if xxx==0 & father_educ==. 		/*NONE OR LESS THAN PRIMARY*/
		replace father_educ=1 if xxx==1 & father_educ==. /*PRIMARY & LOWER SECONDARY*/
		replace father_educ=2 if xxx==2|xxx==3 & father_educ==. /*SECONDARY*/
		replace father_educ=3 if xxx==4|xxx==5 & father_educ==. 		/*TERTIARY*/
		replace father_educ=4 if father_educ==. /*DK/MISSING*/
		replace father_educ=. if elegido!=1
		drop x* temp
		label var father_edu "Father's education" 
	}
	
	
	if country=="Vietnam" {
		*MOTHER'S EDUCATION
		gen 	mother_educ=0 if m7a_q14==1  		    /*NONE OR LESS THAN PRIMARY*/
		replace mother_educ=1 if m7a_q14==2| m7a_q14==3 /*PRIMARY AND LOWER SECONDARY*/
		replace mother_educ=2 if m7a_q14==4		       /*UPPER SECONDARY*/
		replace mother_educ=2 if m7a_q14==5   	       /*POST-SECONDARY, NON-TERTIARY(TOGETHER WITH UPPER SECONDARY)*/
		replace mother_educ=3 if m7a_q14==6|m7a_q14==7 /*TERTIARY*/

		bysort cluster hhn: egen x=max(m7a_q13)  /*Mother's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==99
		bysort cluster hhn: egen xxx=max(temp)  /*Mother's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1
		replace xy=1 if xxx==2
		replace xy=1 if xxx==3
		replace xy=2 if xxx==4
		replace xy=2 if xxx==5
		replace xy=3 if xxx==6|xxx==7
		replace mother_educ=xy if mother_educ==.
		replace mother_educ=4 if mother_educ==. /*DK/MISSING*/
		replace mother_educ=. if elegido!=1
		drop x* temp
		label var mother_edu "Mother's education" 

		*FATHER'S EDUCATION
		gen 	father_educ=0 if m7a_q17==1  		    /*NONE OR LESS THAN PRIMARY*/
		replace father_educ=1 if m7a_q17==2| m7a_q17==3 /*PRIMARY AND LOWER SECONDARY*/
		replace father_educ=2 if m7a_q17==4		       /*UPPER SECONDARY*/
		replace father_educ=2 if m7a_q17==5   	       /*POST-SECONDARY, NON-TERTIARY(TOGETHER WITH UPPER SECONDARY)*/
		replace father_educ=3 if m7a_q17==6|m7a_q17==7 /*TERTIARY*/


		bysort cluster hhn: egen x=max(m7a_q16)  /*father's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==99
		bysort cluster hhn: egen xxx=max(temp)  /*father's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1
		replace xy=1 if xxx==2
		replace xy=1 if xxx==3
		replace xy=2 if xxx==4
		replace xy=2 if xxx==5
		replace xy=3 if xxx==6|xxx==7

		replace father_educ=xy if father_educ==.
		replace father_educ=4 if father_educ==. /*DK/MISSING*/
		replace father_educ=. if elegido!=1
		label var father_edu "Father's education" 
		drop x* temp
	}
	
	
	if country=="Yunnan" {
		/* According to the questionnaire:
		1; no formal education or lower than primary
		2: primary
		3: lower secondary
		4: upper secondary (including vocational and general)
		5; Tertiary, non-degree (including associate degrees)
		6: tertiary degree (bachelor's and master's)
		7: tertiary, Phd
		99: don't know
		*/
		
		*MOTHER'S EDUCATION
		gen mother_educ=. if m7a_q14==99
		replace mother_educ=0 if m7a_q14==1 /*NONE OR LESS THAN PRIMARY*/
		replace mother_educ=1 if m7a_q14==2|m7a_q14==3 /*PRIMARY AND LOWER SECONDARY*/
		replace mother_educ=2 if m7a_q14==4 /*UPPER SECONDARY*/
		replace mother_educ=3 if m7a_q14==5|m7a_q14==6|m7a_q14==7 /*TERTIARY*/
		
		bysort cluster hhn: egen x=max(m7a_q13)  /*Mother's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==99
		bysort cluster hhn: egen xxx=max(temp)  
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1
		replace xy=1 if xxx==2
		replace xy=1 if xxx==3
		replace xy=2 if xxx==4
		replace xy=3 if xxx==5|xxx==6|xxx==7
		replace mother_educ=xy if mother_educ==.
		replace mother_educ=4 if mother_educ==. /*DK/MISSING*/
		replace mother_educ=. if elegido!=1
		drop x* temp
		label var mother_edu "Mother's education" 
	
		*FATHER'S EDUCATION
		gen father_educ=. if m7a_q17==99
		replace father_educ=0 if m7a_q17==1 /*NONE OR LESS THAN PRIMARY*/
		replace father_educ=1 if m7a_q17==2|m7a_q17==3 /*PRIMARY AND LOWER SECONDARY*/
		replace father_educ=2 if m7a_q17==4 /*UPPER SECONDARY*/
		replace father_educ=3 if m7a_q17==5|m7a_q17==6|m7a_q17==7 /*TERTIARY*/
		
		bysort cluster hhn: egen x=max(m7a_q16)  /*father's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==99
		bysort cluster hhn: egen xxx=max(temp)  
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1
		replace xy=1 if xxx==2
		replace xy=1 if xxx==3
		replace xy=2 if xxx==4
		replace xy=3 if  xxx==5|xxx==6|xxx==7

		replace father_educ=xy if father_educ==.
		replace father_educ=4 if father_educ==. /*DK/MISSING*/
		replace father_educ=. if elegido!=1
		label var father_edu "Father's education" 
		drop x* temp	
	}

	*NUMBER OF CHILDREN UNDER 6 YEARS OLD 
	*Number under 6
	gen x=1 if m1a_q04<6 & m1a_q04!=.
	bysort cluster hhn: egen temp=sum(x)
	bysort cluster hhn: egen children=max(temp)
	replace children =. if elegido!=1  
	label var children "Number of children under 6 years old" 
	drop x* temp

	gen _children0=1 if children==0
	recode _children0 (.=0)

	gen _children1=1 if children==1
	recode _children1 (.=0)

	gen _children2=2 if children>=2 & children!=.
	recode _children2 (.=0)

	gen has_children=1 if m7a_q10 ==1
	replace has_children=0 if m7a_q10==2
	
	lab var has_children "respondent is the parent of a child in the hh"
	lab var _children0 "1: no children under 6 in the hh"
	lab var _children1 "1: one child under 6 in the hh"
	lab var _children2 "2: 2 or more children under 6 in the hh"

	*Number under 6 that belong to the respondent (pending)
	/*foreach num in numlist 1/10 {
	bysort cluster hhn: egen temp`num'=max(m7a_q11_`num')  /*Child's id code*/
	gen age`num'=m1a_q04 if idcode==temp`num'
	}*/

	*LABOR MARKET DEPENDENCY 
	/*Number of working hh members/total hh members*/
	gen temp1=1 if m1a_q03!=12 & m1a_q03!=. /*DO NOT COUNT NON RELATIVES AS HH MEMBERS SINCE MANY OF THESE ARE ACTUALLY HH SERVANTS, YET SURVEYS DON'T ALWAYS SPECIFY*/
	bysort cluster hhn: egen hh_size=sum(temp1)
	label var hh_size "HH size, excludes non-relatives"

	gen temp4=1 if m4a_q01==1|m4a_q02==1|m4a_q03==1|m4a_q04==1|m4a_q05==1|m4a_q06==1
	replace temp4=0 if m4a_q01==2 & m4a_q02==2 & m4a_q03==2 & m4a_q04==2 & m4a_q05==2 
	replace temp4=0 if m4a_q06==2
	replace temp4=. if m4a_q06==9

	gen temp2=1 if m1a_q14==1 & temp1==1
	replace temp2=1 if temp4==1 & temp1==1
	replace temp2=. if temp4==0 & temp1==1
	bysort cluster hhn: egen temp3=sum(temp2)  /*Number of working members */
	gen labor_dep=temp3/hh_size 
	label var labor_dep "# employed hh members / hh_size" 
	drop  temp*
	
	*LABEL VARIABLES, GENERATE MAX PARENTS' EDUC
	tab mother_educ
	tab father_educ
	*MAX OF FATHER'S OR MOTHER'S EDUCATION
	gen temp_father=father_educ
	replace temp_father=. if father_educ==4
	gen temp_mother=mother_educ
	replace temp_mother=. if mother_educ==4
	egen max_parent_educ=rowmax(temp_father temp_mother)
	label var max_parent_educ "Maximum of parents' education"
	recode max_parent_educ .=4 if elegido==1
	drop temp*
	tab max_parent_educ

	label define parent_edu 0 "<ISCED 1" 1 "ISCED 1" 2 "ISCED 2 & 3" 3 "ISCED 4 & higher" 4 "DK/RF", replace
	label values mother_educ parent_edu
	label values father_educ parent_edu
	label values max_parent_educ parent_edu
	order max_parent, after(father_ed)

	keep if elegido==1
	
	order  m1a_q01-m1a_q20, after(elegido)
	
	compress
	sort cluster hhn
	save "$pathworkingdata/STEP `country'_working.dta", replace
}


** THE STRUCTURE OF THE DATA FILES WAS SLIGTHLY DIFFERENT FOR UKRAINE
	use "$pathworkingdata/STEP Ukraine_working.dta", clear
	sort cluster hhn idcode
	save "$pathworkingdata/STEP Ukraine_working.dta", replace
	
	use "$pathdataready/STEP Ukraine_HH_Roster_S10.dta", replace
	keep cluster hhn idcode m1a* hh_id
	sort cluster hhn idcode
	merge m:1 cluster hhn idcode using "$pathworkingdata/STEP Ukraine_working.dta"
	drop _merge

	replace country="Ukraine"

	if country=="Ukraine" {
	*MOTHER'S EDUCATION
		gen mother_educ=0 if m7a_q14==0																/* No education */
		replace mother_educ=0 if m7a_q14==1															/*<ISCED 1*/
		replace mother_educ=1 if m7a_q14==2															/*ISCED 1*/
		replace mother_educ=2 if m7a_q14==3 | m7a_q14==4 | m7a_q14==5 | m7a_q14==7 | m7a_q14==10	/*ISCED 2 and 3*/
		replace mother_educ=3 if m7a_q14==6 | m7a_q14==8 | m7a_q14==9 |(m7a_q14>=11 & m7a_q14<=15)	/*ISCED 4 & above*/

		bysort hh_id: egen x=max(m7a_q13)  /*Mother's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==97 | m1a_q09==99
		bysort hh_id: egen xxx=max(temp)  /*Mother's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==0|xxx==1   									/*ISCED < 1*/
		replace xy=1 if xxx==2      									/*ISCED 1*/
		replace xy=2 if xxx==3 											/*ISCED 2*/
		replace xy=2 if xxx==4 | xxx==5 | xxx==7 | xxx==10 				/*ISCED 3*/
		replace xy=3 if xxx==6 | xxx==8 | xxx==9 | (xxx>=11 & xxx<=15) 	/*ISCED 4 and above*/

		replace mother_educ=xy if mother_educ==.
		replace mother_educ=4 if mother_educ==. /*DK/MISSING*/
		drop x* temp
		
		
		label var mother_edu "Mother's education" 
		tab mother_educ

		*FATHER'S EDUCATION
		gen father_educ=0 if m7a_q17==0																/* No education */
		replace father_educ=0 if m7a_q17==1															/*<ISCED 1*/
		replace father_educ=1 if m7a_q17==2															/*ISCED 1*/
		replace father_educ=2 if m7a_q17==3 | m7a_q17==4 | m7a_q17==5 | m7a_q17==7 | m7a_q17==10	/*ISCED 2 and 3*/
		replace father_educ=3 if m7a_q17==6 | m7a_q17==8 | m7a_q17==9 |(m7a_q17>=11 & m7a_q17<=15)	/*ISCED 4 & above*/

		bysort hh_id: egen x=max(m7a_q16)  /*father's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==97 | m1a_q09==99
		bysort hh_id: egen xxx=max(temp)  /*father's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==0|xxx==1   									/*ISCED < 1*/
		replace xy=1 if xxx==2      									/*ISCED 1*/
		replace xy=2 if xxx==3 											/*ISCED 2*/
		replace xy=2 if xxx==4 | xxx==5 | xxx==7 | xxx==10 				/*ISCED 3*/
		replace xy=3 if xxx==6 | xxx==8 | xxx==9 | (xxx>=11 & xxx<=15) 	/*ISCED 4 and above*/

		replace father_educ=xy if father_educ==.
		replace father_educ=4 if father_educ==. /*DK/MISSING*/
		drop x* temp
		
	
		label var father_edu "father's education"
		tab father_educ
	}
	
	if country=="Ukraine"{
	gen x=1 if m1a_q04<6
	bysort hh_id: egen temp=sum(x)
	bysort hh_id: egen children=max(temp)
	replace children =. if elegido!=1  
	label var children "Number of children under 6 years old" 
	drop x* temp

	gen _children0=1 if children==0
	recode _children0 (.=0)

	gen _children1=1 if children==1
	recode _children1 (.=0)

	gen _children2=2 if children>=2 & children!=.
	recode _children2 (.=0)

	/* Bringing question of having children from full questionnaire*/
	rename B11 m7a_q10a
	order m7a_q10a, before(m7a_q10)
	
	gen has_children=1 if m7a_q10a ==1
	replace has_children=0 if m7a_q10a==2
	
	lab var has_children "respondent is the parent of a child in the hh"
	lab var _children0 "1: no children under 6 in the hh"
	lab var _children1 "1: one child under 6 in the hh"
	lab var _children2 "2: 2 or more children under 6 in the hh"
	
	}
	else {
	gen x=1 if m1a_q04<6 & m1a_q04!=.
	bysort cluster hhn: egen temp=sum(x)
	bysort cluster hhn: egen children=max(temp)
	replace children =. if elegido!=1  
	label var children "Number of children under 6 years old" 
	drop x* temp

	gen _children0=1 if children==0
	recode _children0 (.=0)

	gen _children1=1 if children==1
	recode _children1 (.=0)

	gen _children2=2 if children>=2 & children!=.
	recode _children2 (.=0)

	gen has_children=1 if m7a_q10 ==1
	replace has_children=0 if m7a_q10==2
	
	lab var has_children "respondent is the parent of a child in the hh"
	lab var _children0 "1: no children under 6 in the hh"
	lab var _children1 "1: one child under 6 in the hh"
	lab var _children2 "2: 2 or more children under 6 in the hh"
	}
	*Number under 6 that belong to the respondent (pending)
	/*
	foreach num in numlist 1/10 {
	bysort cluster hhn: egen temp`num'=max(m7a_q11_`num')  //Child's id code
	gen age`num'=m1a_q04 if idcode==temp`num'
	*/

	*LABOR MARKET DEPENDENCY 
	/*Number of working hh members/total hh members*/
	
	
	gen temp1=1 if m1a_q03!=12 & m1a_q03!=. /*DO NOT COUNT NON RELATIVES AS HH MEMBERS SINCE MANY OF THESE ARE ACTUALLY HH SERVANTS, YET SURVEYS DON'T ALWAYS SPECIFY*/
		if country=="Ukraine" {
	bysort hh_id: egen hh_size=sum(temp1)
	}
	else {
	bysort cluster hhn: egen hh_size=sum(temp1)
	}
	label var hh_size "HH size, excludes non-relatives"

	gen temp4=1 if m4a_q01==1|m4a_q02==1|m4a_q03==1|m4a_q04==1|m4a_q05==1|m4a_q06==1
	replace temp4=0 if m4a_q01==2 & m4a_q02==2 & m4a_q03==2 & m4a_q04==2 & m4a_q05==2 
	replace temp4=0 if m4a_q06==2
	replace temp4=. if m4a_q06==9

	gen temp2=1 if m1a_q14==1 & temp1==1
	replace temp2=1 if temp4==1 & temp1==1
	replace temp2=. if temp4==0 & temp1==1
	if country=="Ukraine" {
	bysort hh_id: egen temp3=sum(temp2)  /*Number of working members */
	}
	else {
	bysort cluster hhn: egen temp3=sum(temp2)  /*Number of working members */
	}
	gen labor_dep=temp3/hh_size 
	label var labor_dep "# employed hh members / hh_size" 
	drop  temp*
	
	*LABEL VARIABLES, GENERATE MAX PARENTS' EDUC
	tab mother_educ
	tab father_educ
	*MAX OF FATHER'S OR MOTHER'S EDUCATION
	gen temp_father=father_educ
	replace temp_father=. if father_educ==4
	gen temp_mother=mother_educ
	replace temp_mother=. if mother_educ==4
	egen max_parent_educ=rowmax(temp_father temp_mother)
	label var max_parent_educ "Maximum of parents' education"
	recode max_parent_educ .=4 if elegido==1
	drop temp*
	tab max_parent_educ

	label define parent_edu 0 "<ISCED 1" 1 "ISCED 1" 2 "ISCED 2 & 3" 3 "ISCED 4 & higher" 4 "DK/RF", replace
	label values mother_educ parent_edu
	label values father_educ parent_edu
	label values max_parent_educ parent_edu
	order max_parent, after(father_ed)

	keep if elegido==1
	
	order  m1a_q01-m1a_q20, after(elegido)
	compress
	sort cluster hhn
	save "$pathworkingdata/STEP Ukraine_working.dta", replace



**************************************************************************** END OF STEP DO-FILE 4 ******************************************************************
